# OData client

OData client implements configuration entity for OData servers,
IO functions to OData collections and Drupal format OdataQuery object.


## Table of contents

- Requirements
- Installation
- Configuration
- Usage
- Maintainers


## Requirements

The module requires the following library:

  - saintsystems/odata-client: ^0.2.4


## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).


## Configuration

Go to /admin/structure/odata_server and create new server configuration


## Usage

After configuring the server with the default name, it is possible to connect to the server:

```php

$odata_client = \Drupal::service('odata_client.io');
$odata_client->connect('default');
```

#### Change collection:
In configuration can define the default collection but may to change it:

```php

$odata_client->setCollection('People');
```

#### Find an element by key:
Return the data of element key 'russellwhyte':

```php

$result = $odata_client->find('russellwhyte');
```

#### Count elements in collection:
Count the elements in the collection:

```php

$result = $odata_client->count();
```

#### Create new element:
Create a new element in the collection:

```php

$data = array (
  'UserName' => 'teresa',
  'FirstName' => 'Teresa',
  'LastName' => 'Gilbert',
  'Gender' => 'Female',
  'Emails' =>
  array (
    0 => 'teresa@example.com',
    1 => 'teresa@contoso.com',
  ),
  'AddressInfo' =>
  array (
    0 =>
    array (
      'Address' => '1 Suffolk Ln.',
      'City' =>
      array (
        'CountryRegion' => 'United States',
        'Name' => 'Boise',
        'Region' => 'ID',
      ),
    ),
  ),
);
$result = $odata_client->post($data);
```

#### Get data from the collection:
Return max 4 elements FirstName and LastName columns where FirstName is Teresa,
sort by LastName descending:

```php

$query = \Drupal::service('odata_client.query');
$query->connect('default')
    ->fields(['FirstName','LastName'])
    ->condition('FirstName', 'Teresa')
    ->orderBy('LastName', 'desc');
    ->range(0, 4);
$result = $query->execute();
```


## Maintainers

- József Dudás - [dj1999](https://www.drupal.org/u/dj1999)
- Peter Pónya - [pedrop](https://www.drupal.org/u/pedrop)


## Supporting organizations:

- Brainsum Sponsored
